@@ -54,6 +54,8 @@ KEYTYPE_BRANCHWINDOWS,
 KEYTYPE_RAISEAPPLICATION,
 KEYTYPE_BRANCHGUI,
 KEYTYPE_BRANCHGUIACTIONS,
+KEYTYPE_BRANCHGUISELECTION,
+KEYTYPE_BRANCHGUISELECTACTION,
 KEYTYPE_PAGESELECTION,
 KEYTYPE_BRANCHCOMPOSE,
 KEYTYPE_TEXTNAV,
@@ -77,6 +79,8 @@ KEYTYPE_DOCK,
 KEYTYPE_BRANCHMODAL,
 KEYTYPE_MOUSE,
 KEYTYPE_MOUSEBUTTON,
+KEYTYPE_BRANCHLISTITEMS,
+KEYTYPE_BRANCHGUIVALUATOR,
 KEYTYPE_REPEATNEXT
 } GokKeyActionType;
 
@@ -130,8 +134,9 @@ KEYSTYLE_INSENSITIVE
 /* if you add data members to this structure, initialize them in gok_keylabel_new */
 typedef struct GokKeyLabel{
 	gchar* Text;
-        guint  modifiers;
-	guint  mod_mask;
+        guint  level;
+        guint  group;
+	gchar* vmods; /* currently unused; see bug # */
 	struct GokKeyLabel* pLabelNext;	
 } GokKeyLabel;
 
@@ -190,7 +195,7 @@ typedef struct GokKey{
 	guint has_image:1;
 	guint is_repeatable:1;
         guint unused:13; /* nicer alignment in case compiler is weird */
-	AccessibleNode* pNodeAccessible;
+	AccessibleNode* accessible_node;
 	gint CellsRequired;
 	gint FontSizeGroup;
 	gint FontSize;
@@ -222,7 +227,7 @@ typedef struct GokKey{
 } GokKey;
 
 gboolean gok_key_initialize (GokKey* pKey, xmlNode* pNode);
-gboolean gok_key_add_label (GokKey* pKey, gchar* pLabelText, guint modifiers, guint mod_mask);
+gboolean gok_key_add_label (GokKey* pKey, gchar* pLabelText, guint level, guint group, const gchar *vmods);
 void gok_key_set_output (GokKey* pKey, gint Type, gchar* pName, AccessibleKeySynthType Flag);
 void gok_key_add_output (GokKey* pKey, gint Type, gchar* pName, AccessibleKeySynthType Flag);
 void gok_key_change_label (GokKey* pKey, gchar* LabelText);
@@ -238,7 +243,7 @@ GtkWidget* gok_key_create_image_widget (GokKey* pKey);
 GokKeyImage* gok_key_get_image (GokKey* pKey);
 gchar* gok_key_get_image_filename (GokKey* pKey);
 gchar* gok_key_get_label (GokKey* pKey);
-GokKeyLabel* gok_keylabel_new (GokKey* pKey, gchar* pLabelText, guint modifiers, guint mod_mask);
+GokKeyLabel* gok_keylabel_new (GokKey* pKey, gchar* pLabelText, guint level, guint group, const gchar *vmods);
 void gok_keylabel_delete (GokKeyLabel* pKeyLabel);
 void gok_key_update_toggle_state (GokKey *pKey);
 void gok_key_set_cells(GokKey* pKey, gint top, gint bottom, gint left, gint right);
