@@ -105,13 +105,13 @@ gunichar gok_output_unichar_from_keysym (KeySym keysym, guint mods)
 		Display *display;
 		if (gok_main_get_main_window ()) 
 		{
+		        long ucs;
 			display = GDK_WINDOW_XDISPLAY (gok_main_get_main_window ()->window);
-			/* hmm, how do we know XkbTranslateKeySym will use UTF-8 ? */
 			nbytes = MIN (XkbTranslateKeySym (display,
 							  &keysym, mods, buf, 19, &extra_rtn), 19); 
-			if (nbytes) {
-			  fprintf (stderr, "unichar is [%s]\n", buf);
-				return g_utf8_get_char_validated (buf, nbytes);
+			if ((ucs = keysym2ucs (keysym)) > 0) 
+			{
+			    return (gunichar) ucs;
 			}
 		}
 		return 0;
@@ -344,6 +344,21 @@ void gok_output_send_to_system (GokOutput* pOutput, gboolean bWordCompletion)
 	gok_log_leave();
 }
 
+/**
+ *
+ * Returns keycode for OUTPUT_KEYCODE keys, or -1.
+ **/
+int 
+gok_output_get_keycode (GokOutput *output)
+{
+    int keycode = -1;
+    if (output && output->Type == OUTPUT_KEYCODE)
+	keycode = atoi (output->Name);
+
+    return keycode;
+}
+
+
 void
 gok_output_internal (gchar* action)
 {
