@@ -83,7 +83,7 @@ gboolean gok_page_accessmethod_initialize (GtkWidget* pWindowSettings)
 	
 	/* backup the initial settings */
 	gok_page_accessmethod_backup();
-	
+
 	/* add the names of all the access methods to the combo box */
 	pAccessMethod = gok_scanner_get_first_access_method();
 	g_assert (pAccessMethod != NULL);
@@ -110,6 +110,8 @@ gboolean gok_page_accessmethod_initialize (GtkWidget* pWindowSettings)
 	g_assert (pEntryAccessMethodName != NULL);
 	gtk_entry_set_text (GTK_ENTRY (pEntryAccessMethodName), gok_page_accessmethod_get_displayname (m_NameAccessMethod));
 
+	gok_page_accessmethod_change_controls (m_NameAccessMethod);
+
 	return TRUE;
 }
 
@@ -561,6 +563,7 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 	gchar* settingString;
 	GokFilledCombo* pFilledComboNew;
 	GokFilledCombo* pFilledComboTemp;
+	AtkObject* atko;
 
 	while (pControl != NULL)
 	{
@@ -626,6 +629,8 @@ void gok_page_accessmethod_draw_controls (gchar* NameAccessMethod, GokControl* p
 						gtk_widget_ref (pWidget);
 						gtk_object_set_data_full (GTK_OBJECT (gok_settingsdialog_get_window()), pControlName, pWidget,
 						                            (GtkDestroyNotify) gtk_widget_unref);
+						atko = gtk_widget_get_accessible (pWidget);
+						atk_object_set_name (atko, pControl->String ? pControl->String : "");
 						gtk_widget_show (pWidget);
 						gtk_box_pack_start (GTK_BOX (pControlParent->pWidget), pWidget, FALSE, FALSE, 0);
 
