@@ -56,6 +56,7 @@ gboolean gok_windowlister_show()
 	GokKey* pKey;
 	GokKey* pKeyPrevious;
 	int column;
+	gchar *window_name = NULL;
     GList *window_list_entry;
 
 /*    GType window_type; */
@@ -75,7 +76,6 @@ gboolean gok_windowlister_show()
 	
 	if (pKeyboard == NULL)
 	{
-		/* no accessible text keyboard so create one */
 		gok_log ("creating window list keyboard..");
 		pKeyboardNew = gok_keyboard_new();
 		if (pKeyboardNew == NULL)
@@ -126,7 +126,7 @@ gboolean gok_windowlister_show()
 	pKey->Bottom = 1;
 	pKey->Left = 0;
 	pKey->Right = 1;
-	gok_key_add_label (pKey, _("back"), 0, 0);
+	gok_key_add_label (pKey, _("back"), 0, 0, NULL);
 	pKeyPrevious = pKey;
 
 	/* build window keys */
@@ -148,8 +148,9 @@ gboolean gok_windowlister_show()
 			pKey->Bottom = 1;
 			pKey->Left = column;
 			pKey->Right = column + 1;
-			
-			gok_key_add_label (pKey, (char*)(wnck_window_get_name (window_list_entry->data)), 0, 0);
+			window_name = wnck_window_get_name (window_list_entry->data);
+			if (!window_name) window_name = g_strdup ("");
+			gok_key_add_label (pKey, window_name, 0, 0, NULL);
 			
 			pKey->pGeneral = window_list_entry->data;  
 	
