@@ -52,15 +52,15 @@ static GokWordCompletionCharacterCategory gok_wordcomplete_real_unichar_get_cate
 	                                         GokWordComplete *complete, gunichar letter);
 static gchar **gok_wordcomplete_real_predict (GokWordComplete *complete, gint num_predictions);
 static gchar *gok_wordcomplete_real_get_word_part (GokWordComplete *complete);
-static gchar *  gok_wordcomplete_real_get_aux_dict (GokWordComplete *complete);
-static gboolean gok_wordcomplete_real_set_aux_dict (GokWordComplete *complete, const gchar *dict_path);
+static const gchar *  gok_wordcomplete_real_get_aux_dict (GokWordComplete *complete);
+static gboolean gok_wordcomplete_real_set_aux_dict (GokWordComplete *complete, gchar *dict_path);
 
 struct _GokWordCompletePrivate 
 {
         /* the word, or part word, that is getting completed */
 	gchar     *word_part;
 	gunichar     compose;
-	const gchar *aux_dictionaries;
+	gchar *aux_dictionaries;
 };
 
 static GokWordComplete *default_wordcomplete_engine = NULL;
@@ -316,7 +316,7 @@ gok_wordcomplete_increment_word_frequency (GokWordComplete *complete, const gcha
 * 
 * returns: a fully-delimited file path to an auxiliary word prediction dictionary
 **/
-gchar*   
+const gchar*   
 gok_wordcomplete_get_aux_dictionaries (GokWordComplete *complete)
 {
 	GokWordCompleteClass *klass = GOK_WORDCOMPLETE_GET_CLASS (complete);
@@ -332,7 +332,7 @@ gok_wordcomplete_get_aux_dictionaries (GokWordComplete *complete)
 * returns: TRUE if an aux dictionary can be used by the word-completion engine, FALSE otherwise.
 **/
 gboolean 
-gok_wordcomplete_set_aux_dictionaries (GokWordComplete *complete, const gchar *dictionary_path)
+gok_wordcomplete_set_aux_dictionaries (GokWordComplete *complete, gchar *dictionary_path)
 {
 	GokWordCompleteClass *klass = GOK_WORDCOMPLETE_GET_CLASS (complete);
 	if (*klass->set_aux_dictionary)
@@ -636,7 +636,7 @@ gok_wordcomplete_real_get_word_part (GokWordComplete *complete)
 
 /**
  **/
-static gchar *
+static const gchar *
 gok_wordcomplete_real_get_aux_dict (GokWordComplete *complete)
 {
 	return complete->priv->aux_dictionaries;
@@ -645,7 +645,7 @@ gok_wordcomplete_real_get_aux_dict (GokWordComplete *complete)
 /**
  **/
 static gboolean
-gok_wordcomplete_real_set_aux_dict (GokWordComplete *complete, const gchar *dict_path)
+gok_wordcomplete_real_set_aux_dict (GokWordComplete *complete, gchar *dict_path)
 {
 	if (complete && complete->priv)
 		complete->priv->aux_dictionaries = dict_path;
